@@ -19,15 +19,14 @@
 #' points(x,y,pch=21,bg='black')
 #' @export
 ellipse <- function(x,y,covmat,alpha=0.05,n=50){
-    nn <- 50
     cutoff <- stats::qchisq(1-alpha,2)
     e <- eigen(covmat)
     a <- sqrt(cutoff*abs(e$values[1])) # major axis
     b <- sqrt(cutoff*abs(e$values[2])) # minor axis
     v <- e$vectors[,1] # largest eigenvector
     beta <- atan(v[2]/v[1]) # rotation angle of the ellipse
-    theta <- seq(0, 2 * pi, length=nn)
-    out <- matrix(0,nrow=nn,ncol=2)
+    theta <- seq(0, 2 * pi, length=n)
+    out <- matrix(0,nrow=n,ncol=2)
     out[,1] <- x + a * cos(theta) * cos(beta) - b * sin(theta) * sin(beta)
     out[,2] <- y + a * cos(theta) * sin(beta) + b * sin(theta) * cos(beta)
     colnames(out) <- c('x','y')
