@@ -103,7 +103,7 @@ peakfit.default <- function(x,k='auto',sigdig=2,log=TRUE,alpha=0.05,...){
         X[,1] <- log(X[,1])
     }
     if (identical(k,'min')) {
-        out <- min_age_model(X,alpha=alpha)
+        out <- min_age_model(X,alpha=alpha,...)
     } else if (identical(k,'auto')) {
         out <- normal.mixtures(X,k=BIC_fit(X,5),alpha=alpha,...)
     } else {
@@ -279,7 +279,7 @@ peakfit_helper <- function(x,k=1,type=4,cutoff.76=1100,cutoff.disc=discfilter(),
     if (k<1) return(NULL)
     if (identical(k,'auto')){
         k <- BIC_fit(x,5,log=log,type=type,cutoff.76=cutoff.76,
-                     cutoff.disc=cutoff.disc,detritus=detritus,commonPb=common.Pb)
+                     cutoff.disc=cutoff.disc,detritus=detritus,common.Pb=common.Pb)
     }
     tt <- get.ages(x,i2i=i2i,common.Pb=common.Pb,type=type,cutoff.76=cutoff.76,
                    cutoff.disc=cutoff.disc,detritus=detritus,...)
@@ -507,15 +507,12 @@ theta2age <- function(x,theta,beta.var,exterr=TRUE){
     list(peaks=peaks,peaks.err=peaks.err)
 }
 
-BIC_fit <- function(x,max.k,type=4,cutoff.76=1100,cutoff.disc=discfilter(),
-                    exterr=TRUE,detritus=0,common.Pb=0,...){
+BIC_fit <- function(x,max.k,...){
     n <- length(x)
     BIC <- Inf
     tryCatch({
         for (k in 1:max.k){
-            fit <- peakfit(x,k,type=type,cutoff.76=cutoff.76,
-                           cutoff.disc=cutoff.disc,exterr=exterr,
-                           detritus=detritus,common.Pb=common.Pb,...)
+            fit <- peakfit(x,k,...)
             p <- 2*k-1
             newBIC <- -2*fit$L+p*log(n)
             if (newBIC<BIC) {
@@ -530,7 +527,6 @@ BIC_fit <- function(x,max.k,type=4,cutoff.76=1100,cutoff.disc=discfilter(),
     }) 
 }
 
-# Simple 3-parameter Normal model (Section 6.11 of Galbraith, 2005)
 min_age_model <- function(zs,alpha=0.05,np=4){
     imin <- which.min(zs[,1])
     mz <- zs[imin,1]
@@ -606,5 +602,7 @@ get.minage.L <- function(pars,zs){
     EE <- 1-stats::pnorm((gam-mu)/s)
     FF <- -0.5*((z-mu)^2)/(sig^2+s^2)
     fu <- AA*exp(BB) + CC*(DD/EE)*exp(FF)
+    fu[fu<.Machine$double.xmin] <- .Machine$double.xmin
+    fu[fu>.Machine$double.xmax] <- .Machine$double.xmax
     sum(-log(fu))
 }
